@@ -79,11 +79,9 @@ export const LogLineContext = memo(
     getRowContextQuery,
     onClose,
     getRowContext,
-    displayedFields = [],
+    displayedFields: displayedFieldsProp = [],
     logLineMenuCustomItems,
     onPermalinkClick,
-    onClickShowField,
-    onClickHideField,
   }: LogLineContextProps) => {
     const containerRef = useRef<HTMLDivElement | null>(null);
     const [contextQuery, setContextQuery] = useState<DataQuery | null>(null);
@@ -101,6 +99,7 @@ export const LogLineContext = memo(
       ? (store.get(`${logOptionsStorageKey}.contextTimeWindow`) ?? DEFAULT_TIME_WINDOW.toString())
       : DEFAULT_TIME_WINDOW.toString();
     const [timeWindow, setTimeWindow] = useState(parseInt(defaultTimeWindow, 10));
+    const [displayedFields, setDisplayedFields] = useState<string[]>(displayedFieldsProp);
 
     const eventBusRef = useRef(new EventBusSrv());
 
@@ -287,6 +286,33 @@ export const LogLineContext = memo(
       setInitialized(false);
     }, [updateContextQuery]);
 
+    const resetFields = useCallback(() => {
+      setDisplayedFields([]);
+    }, []);
+
+    const showField = useCallback(
+      (key: string) => {
+        const index = displayedFields.indexOf(key);
+
+        if (index === -1) {
+          const updatedDisplayedFields = displayedFields.concat(key);
+          setDisplayedFields(updatedDisplayedFields);
+        }
+      },
+      [displayedFields]
+    );
+
+    const hideField = useCallback(
+      (key: string) => {
+        const index = displayedFields.indexOf(key);
+        if (index > -1) {
+          const updatedDisplayedFields = displayedFields.filter((k) => key !== k);
+          setDisplayedFields(updatedDisplayedFields);
+        }
+      },
+      [displayedFields]
+    );
+
     const wrapLogMessage = logOptionsStorageKey ? store.getBool(`${logOptionsStorageKey}.wrapLogMessage`, true) : true;
     const syntaxHighlighting = logOptionsStorageKey
       ? store.getBool(`${logOptionsStorageKey}.syntaxHighlighting`, true)
@@ -329,7 +355,6 @@ export const LogLineContext = memo(
           <div>{getLogRowContextUi(log, updateResults)}</div>
         )}
         <Collapse
-          collapsible={true}
           isOpen={showLog}
           onToggle={() => setShowLog(!showLog)}
           className={styles.referenceLogLine}
@@ -338,36 +363,52 @@ export const LogLineContext = memo(
           <LogLineDetailsLog log={logListModel} syntaxHighlighting={syntaxHighlighting} />
         </Collapse>
         <div className={styles.controls}>
-          {datasourceInstance?.supportsAdjustableWindow && (
-            <Stack>
-              <InlineLabel
-                htmlFor="time-window-control"
+          <div className={styles.controlGroup}>
+            {datasourceInstance?.supportsAdjustableWindow && (
+              <Stack>
+                <InlineLabel
+                  htmlFor="time-window-control"
+                  tooltip={t(
+                    'logs.log-line-context.time-window-tooltip',
+                    'Amount of time before and after the referenced log'
+                  )}
+                  width="auto"
+                >
+                  {t('logs.log-line-context.time-window-label', 'Context time window')}
+                </InlineLabel>
+                <Combobox
+                  id="time-window-control"
+                  options={getTimeWindowOptions()}
+                  onChange={handleTimeWindowChange}
+                  value={timeWindow.toString()}
+                  minWidth={5}
+                  width="auto"
+                />
+              </Stack>
+            )}
+            {displayedFields.length > 0 && (
+              <Button
+                variant="secondary"
+                onClick={resetFields}
                 tooltip={t(
-                  'logs.log-line-context.time-window-tooltip',
-                  'Amount of time before and after the referenced log'
+                  'logs.log-line-context.show-original-log-tooltip',
+                  'Clear displayed fields and show the original log line message'
                 )}
-                width="auto"
               >
-                {t('logs.log-line-context.time-window-label', 'Context time window')}
-              </InlineLabel>
-              <Combobox
-                id="time-window-control"
-                options={getTimeWindowOptions()}
-                onChange={handleTimeWindowChange}
-                value={timeWindow.toString()}
-                minWidth={5}
-                width="auto"
-              />
-            </Stack>
-          )}
-          <Button variant="secondary" onClick={onScrollCenterClick}>
-            <Trans i18nKey="logs.log-line-context.center-matched-line">Center matched line</Trans>
-          </Button>
-          {contextQuery?.datasource?.uid && (
-            <Button variant="secondary" onClick={onSplitViewClick}>
-              <Trans i18nKey="logs.log-line-context.open-in-split-view">Open in split view</Trans>
+                <Trans i18nKey="logs.log-line-context.show-original-log">Show original logs</Trans>
+              </Button>
+            )}
+          </div>
+          <div className={styles.controlGroup}>
+            <Button variant="secondary" onClick={onScrollCenterClick}>
+              <Trans i18nKey="logs.log-line-context.center-matched-line">Center matched line</Trans>
             </Button>
-          )}
+            {contextQuery?.datasource?.uid && (
+              <Button variant="secondary" onClick={onSplitViewClick}>
+                <Trans i18nKey="logs.log-line-context.open-in-split-view">Open in split view</Trans>
+              </Button>
+            )}
+          </div>
         </div>
         <div className={styles.loadingIndicator}>
           {aboveState === LoadingState.Loading && (
@@ -389,6 +430,7 @@ export const LogLineContext = memo(
               <LogList
                 app={CoreApp.Unknown}
                 containerElement={containerRef.current}
+                dataFrames={[]}
                 dedupStrategy={LogsDedupStrategy.none}
                 detailsMode="inline"
                 displayedFields={displayedFields}
@@ -397,13 +439,16 @@ export const LogLineContext = memo(
                 infiniteScrollMode="unlimited"
                 loadMore={handleLoadMore}
                 logLineMenuCustomItems={logLineMenuCustomItems}
+                logOptionsStorageKey={logOptionsStorageKey}
                 logs={allLogs}
                 loading={aboveState === LoadingState.Loading || belowState === LoadingState.Loading}
                 permalinkedLogId={log.uid}
                 onPermalinkClick={onPermalinkClick}
-                onClickHideField={onClickHideField}
-                onClickShowField={onClickShowField}
+                onClickHideField={hideField}
+                onClickShowField={showField}
+                setDisplayedFields={setDisplayedFields}
                 showControls
+                showFieldSelector={false}
                 showTime={logOptionsStorageKey ? store.getBool(`${logOptionsStorageKey}.showTime`, true) : true}
                 sortOrder={sortOrder}
                 syntaxHighlighting={syntaxHighlighting}
@@ -485,8 +530,23 @@ const getStyles = (theme: GrafanaTheme2) => {
     }),
     controls: css({
       display: 'flex',
-      justifyContent: 'flex-end',
+      justifyContent: 'space-between',
       gap: theme.spacing(2),
+      [theme.breakpoints.down('sm')]: {
+        flexDirection: 'column',
+      },
+    }),
+    controlGroup: css({
+      display: 'flex',
+      gap: theme.spacing(1),
+      flexDirection: 'row',
+      [theme.breakpoints.down('lg')]: {
+        flexDirection: 'column',
+        alignItems: 'flex-start',
+      },
+      [theme.breakpoints.down('sm')]: {
+        alignItems: 'center',
+      },
     }),
   };
 };
